/****************************************************************************
** Meta object code from reading C++ file 'qgeoareamonitorsource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtpositioning/src/positioning/qgeoareamonitorsource.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qgeoareamonitorsource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QGeoAreaMonitorSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto QGeoAreaMonitorSource::qt_create_metaobjectdata<qt_meta_tag_ZN21QGeoAreaMonitorSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QGeoAreaMonitorSource",
        "areaEntered",
        "",
        "QGeoAreaMonitorInfo",
        "monitor",
        "QGeoPositionInfo",
        "update",
        "areaExited",
        "monitorExpired",
        "errorOccurred",
        "QGeoAreaMonitorSource::Error",
        "error",
        "Error",
        "AccessError",
        "InsufficientPositionInfo",
        "UnknownSourceError",
        "NoError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'areaEntered'
        QtMocHelpers::SignalData<void(const QGeoAreaMonitorInfo &, const QGeoPositionInfo &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'areaExited'
        QtMocHelpers::SignalData<void(const QGeoAreaMonitorInfo &, const QGeoPositionInfo &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'monitorExpired'
        QtMocHelpers::SignalData<void(const QGeoAreaMonitorInfo &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(QGeoAreaMonitorSource::Error)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Error'
        QtMocHelpers::EnumData<enum Error>(12, 12, QMC::EnumFlags{}).add({
            {   13, Error::AccessError },
            {   14, Error::InsufficientPositionInfo },
            {   15, Error::UnknownSourceError },
            {   16, Error::NoError },
        }),
    };
    return QtMocHelpers::metaObjectData<QGeoAreaMonitorSource, qt_meta_tag_ZN21QGeoAreaMonitorSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QGeoAreaMonitorSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QGeoAreaMonitorSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QGeoAreaMonitorSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QGeoAreaMonitorSourceE_t>.metaTypes,
    nullptr
} };

void QGeoAreaMonitorSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QGeoAreaMonitorSource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->areaEntered((*reinterpret_cast<std::add_pointer_t<QGeoAreaMonitorInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGeoPositionInfo>>(_a[2]))); break;
        case 1: _t->areaExited((*reinterpret_cast<std::add_pointer_t<QGeoAreaMonitorInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGeoPositionInfo>>(_a[2]))); break;
        case 2: _t->monitorExpired((*reinterpret_cast<std::add_pointer_t<QGeoAreaMonitorInfo>>(_a[1]))); break;
        case 3: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QGeoAreaMonitorSource::Error>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGeoAreaMonitorInfo >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGeoPositionInfo >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGeoAreaMonitorInfo >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGeoPositionInfo >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGeoAreaMonitorInfo >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QGeoAreaMonitorSource::*)(const QGeoAreaMonitorInfo & , const QGeoPositionInfo & )>(_a, &QGeoAreaMonitorSource::areaEntered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QGeoAreaMonitorSource::*)(const QGeoAreaMonitorInfo & , const QGeoPositionInfo & )>(_a, &QGeoAreaMonitorSource::areaExited, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QGeoAreaMonitorSource::*)(const QGeoAreaMonitorInfo & )>(_a, &QGeoAreaMonitorSource::monitorExpired, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QGeoAreaMonitorSource::*)(QGeoAreaMonitorSource::Error )>(_a, &QGeoAreaMonitorSource::errorOccurred, 3))
            return;
    }
}

const QMetaObject *QGeoAreaMonitorSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGeoAreaMonitorSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QGeoAreaMonitorSourceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QGeoAreaMonitorSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QGeoAreaMonitorSource::areaEntered(const QGeoAreaMonitorInfo & _t1, const QGeoPositionInfo & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QGeoAreaMonitorSource::areaExited(const QGeoAreaMonitorInfo & _t1, const QGeoPositionInfo & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void QGeoAreaMonitorSource::monitorExpired(const QGeoAreaMonitorInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QGeoAreaMonitorSource::errorOccurred(QGeoAreaMonitorSource::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
